View source: R/10-terrain-analysis.R
| calculate_advanced_terrain_metrics | R Documentation |
Calculate advanced terrain metrics from DEM including curvature, wetness index, and stream power index.
calculate_advanced_terrain_metrics(
elevation_raster,
metrics = c("wetness_index", "curvature", "convergence"),
region_boundary = NULL
)
elevation_raster |
Digital elevation model |
metrics |
Vector of metrics to calculate |
region_boundary |
Optional region boundary |
List of terrain metric rasters
## Not run:
# These examples require external data files not included with the package
# Calculate advanced terrain metrics
terrain_metrics <- calculate_advanced_terrain_metrics(
elevation_raster = "dem.tif",
metrics = c("wetness_index", "curvature", "convergence"),
region_boundary = "watershed.shp"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.