| test_package_minimal | R Documentation |
Ultra-minimal test that only checks the most basic functionality. Designed to always pass if the package is minimally functional.
test_package_minimal(verbose = FALSE)
verbose |
Print messages |
Logical indicating basic functionality
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.